@@ -41,6 +41,12 @@ parser.add_argument(
     action="store_true",
     help="run email setup wizard",
 )
+parser.add_argument(
+    "-E",
+    "--test-email",
+    action="store_true",
+    help="send a test email with current credentials"
+)
 parser.add_argument(
     "-d",
     "--domain",
