@@ -7,7 +7,7 @@ from requests import get, post
 from domains_api.exceptions import UserNotSetup, UserInstanceNotRecognised
 from domains_api.file_handlers import FileHandlers
 from domains_api.arg_parser import parser
-from domains_api.constants import __VERSION__
+from domains_api.constants import __VERSION__, api_responses
 from domains_api.user import User
 
 
@@ -64,36 +64,26 @@ class IPChanger:
 
     def parse_api_response(self, response: str) -> bool:
         """Parse response from Google Domains API call"""
-        log_msg = "DDNS API response: %s" % response
-        self.fh.log(log_msg, "info")
-
-        # Successful request:
-        if "good" in response:
-            self.user.send_notification(self.user.last_ip)
-            log_msg = f"IP changed successfully to {self.user.last_ip}"
-            self.fh.log(log_msg, "info")
-            return True
-        if "nochg" in response:
-            log_msg = "No change to IP"
-            self.fh.log(log_msg, "info")
-            return True
-        # Unsuccessful requests:
-        if response in {"nohost", "notfqdn"}:
-            msg = (
-                "The hostname does not exist, is not a fully qualified domain"
-                " or does not have Dynamic DNS enabled. The script will not be "
-                "able to run until you fix this. See https://support.google.com/domains/answer/6147083?hl=en-CA"
-                " for API documentation"
-            )
-            self.fh.log(msg, "warning")
-            self.user.send_notification(self.user.last_ip, "error", msg)
+        keys = api_responses.keys()
+        for key in keys:
+            if key in response:
+                response_data = api_responses[key]
+                break
+        help_text = f'API response: {response}: {response_data["help_text"]}'
+        status = response_data["status"]
+        if not status:
+            help_text += " ...see https://support.google.com/domains/answer/6147083?hl=en-CA "\
+                         "for API documentation"
+        log_type = "info" if status else "warning"
+        self.fh.log(help_text, log_type)
+        if 'good' in response:
+            ip = response.split()[1]
+            self.user.send_notification(ip)
+        elif 'nochg' in response:
+            pass
         else:
-            self.fh.log(
-                "Could not authenticate with current credentials\n"
-                "Hint: run `domains -p` to run setup wizard",
-                "warning",
-            )
-        return False
+            self.user.send_notification(type="error", error=f"{response}: {help_text}", log_fn=self.fh.log)
+        return not not status
 
     def check_user(self):
         if self.user is None:
@@ -127,6 +117,10 @@ class IPChanger:
             return
         if opts.email:
             self.user.email_wizard()
+            if not opts.test_email:
+                return
+        if opts.test_email:
+            self.user.send_test_message(self.fh.log)
             return
         if opts.notify:
             notification_state = self.user.toggle_notifications(opts.notify)
@@ -142,10 +136,13 @@ class IPChanger:
             self.fh.log("***Forcing API call***", "info")
             if type(opts.force) == str:
                 pattern = r"(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})"
-                if re.search(pattern, opts.force):
+                if re.search(pattern, opts.force.strip()):
                     self.user.last_ip = opts.force
                     self.fh.log(f"Overriding IP: {opts.force}", "info")
                     self.fh.save_user(self.user)
+                else:
+                    print(f"'{opts.force}' is not a recognised IPv4 address")
+                    print("Using last IP")
             self.parse_api_response(self.call_api(self.user.last_ip))
 
     def user_setup_wizard(self):
